@@ -9,10 +9,12 @@ pub(crate) fn create_kmip_client<T>(tls_stream: T, conn_settings: &ConnectionSet
         client = client.with_credentials(username.clone(), conn_settings.password.clone());
     }
 
+    let mut reader_config = KmipConfig::default().with_read_buf();
     if let Some(max_bytes) = conn_settings.max_response_bytes {
-        let reader_config = KmipConfig::default().with_max_bytes(max_bytes).with_read_buf();
-        client = client.with_reader_config(reader_config);
+        reader_config = reader_config.with_max_bytes(max_bytes);
     };
 
+    client = client.with_reader_config(reader_config);
+
     client.build()
 }
